@@ -5,7 +5,11 @@ from islatu import image
 from islatu import io
 from islatu import refl_data
 from islatu import stitching
-from yaml import load, CLoader
+from yaml import load
+try:
+    from yaml import CLoader as Loader, CDumper as Dumper
+except ImportError:
+    from yaml import Loader, Dumper
 import datetime
 from os import path
 from ast import literal_eval as make_tuple
@@ -70,18 +74,18 @@ class Foreperson:
             self.directory_path = directory_path
         else:
             raise FileNotFoundError("The experiment directory cannot be found.")
-        self.header = ' creator:\n   name:'+self.creator['name']+'\n'
-                      '   affiliation:'+self.creator['affiliation']+'\n'
-                      '   time:'+self.creator['time']+'\n data source:\n'
-                      '   experiment:\n     '
-                      'probe:'+self.data_source['experiment']['probe']+'\n     '
-                      'instrument:'+self.data_source['experiment']['instrument']+'\n     '
-                      'sample:'+self.data_source['experiment']['sample']+'\n '
-                      'reduction:\n   software:'+self.reduction['software']+'\n   '
-                      'yaml:'+self.reduction['yaml']+'\n data:\n   '
-                      'column 1:'+self.data['column 1']+'\n   '
-                      'column 2:'+self.data['column 2']+'\n   '
-                      'column 3:'+self.data['column 3']+''
+        self.header = ' creator:\n   name:'+self.creator['name']+'\n'\
+                      '   affiliation:'+self.creator['affiliation']+'\n'\
+                      '   time:'+self.creator['time']+'\n data source:\n'\
+                      '   experiment:\n     '\
+                      'probe:'+self.data_source['experiment']['probe']+'\n     '\
+                      'instrument:'+self.data_source['experiment']['instrument']+'\n     '\
+                      'sample:'+self.data_source['experiment']['sample']+'\n '\
+                      'reduction:\n   software:'+self.reduction['software']+'\n   '\
+                      'yaml:'+self.reduction['yaml']+'\n data:\n   '\
+                      'column 1:'+self.data['column 1']+'\n   '\
+                      'column 2:'+self.data['column 2']+'\n   '\
+                      'column 3:'+self.data['column 3']
         if self.n_columns == 4:
             self.header += '\n   column 4:'+self.data['column 4']
 
@@ -94,10 +98,10 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=Non
     yaml_file (:py:attr:`str`): File path to instruction set.
     metadata (:py:attr:`dict`): If metadata should be included in the outpuit
         file, pass this as a :py:attr:`dict`.
-    """1
+    """
     the_boss = Foreperson(metadata)
     y_file = open(yaml_file, 'r')
-    recipe = load(y_file, Loader=CLoader)
+    recipe = load(y_file, Loader=Loader)
     y_file.close()
     the_boss.reduction['yaml'] = yaml_file
     keys = recipe.keys()
@@ -215,9 +219,9 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=Non
     if the_boss.q_min is None:
         refl.rebin(number_of_q_vectors=the_boss.n_qvectors)
     else:
-        if the_boss.q_space is 'linear':
+        if the_boss.q_space == 'linear':
             spacing = np.linspace
-        elif the_boss.q_space is 'log':
+        elif the_boss.q_space == 'log':
             spacing = np.logspace
         refl.rebin(new_q=spacing(the_boss.q_min, the_boss.q_max, the_boss.q_step))
 
